# Python Simplifier

A module to assist in simplifying your python experience

## How to install:
* Windows: `pip install python-simplifier`
* Mac/Linux: `pip3 install python-simplifier`


### Links:
* [Github](https://github.com/ametsch/python-simplifier)
* [PyPI](https://pypi.org/project/python-simplifier/)